@@ -1,8 +1,8 @@
 // Use LANG environment variable to choose locale
 pref("intl.locale.matchOS", true);
 
-// Fall back to en-US search plugins if none exist for the current locale
-pref("distribution.searchplugins.defaultLocale", "en-US");
-
 // Enable Network Manager integration
 pref("network.manage-offline-status", true);
+
+// Enable unsigned addons in the application scope
+pref("extensions.unsignedScopes", 4, locked);
